@@ -9,6 +9,7 @@ import time
 import glob
 import os
 import calendar
+import shutil
 
 from datetime import datetime
 from datetime import timedelta
@@ -340,6 +341,20 @@ def find_files_in_archives_pattern(relative_path, archive_roots):
     log.debug("Found the following opt composite files:{}".format(filepaths))
     return filepaths
 
+def copy_files_from_archive(scrfiles_path, dst_folder):
+    if type(scrfiles_path) == list:
+        for scrfile_path_item in scrfiles_path:
+            if 's3archive' in str(scrfile_path_item):
+                pass
+            else:
+                copied_path = Path(dst_folder).joinpath(Path(scrfile_path_item).name)
+                copy_singlefile_from_archive(scrfile_path_item, copied_path)
+    else:
+        copied_path = Path(dst_folder).joinpath(Path(scrfiles_path).name)
+        copy_singlefile_from_archive(scrfiles_path, copied_path)
+
+def copy_singlefile_from_archive(scrfile_path, dstfile_path):
+    shutil.copy(str(scrfile_path), str(dstfile_path))
 #################################################################################################
 #################################################################################################
 
